@@ -69,7 +69,7 @@ struct _GstFFMpegMuxClass
 {
   GstElementClass parent_class;
 
-  AVOutputFormat *in_plugin;
+  const AVOutputFormat *in_plugin;
 };
 
 #define GST_TYPE_FFMPEGMUX \
@@ -192,7 +192,7 @@ gst_ffmpegmux_base_init (gpointer g_class)
   GstFFMpegMuxClass *klass = (GstFFMpegMuxClass *) g_class;
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
   GstPadTemplate *videosinktempl, *audiosinktempl, *srctempl;
-  AVOutputFormat *in_plugin;
+  const AVOutputFormat *in_plugin;
   GstCaps *srccaps, *audiosinkcaps, *videosinkcaps;
   enum AVCodecID *video_ids = NULL, *audio_ids = NULL;
   gchar *longname, *description, *name;
@@ -332,7 +332,7 @@ gst_ffmpegmux_init (GstFFMpegMux * ffmpegmux, GstFFMpegMuxClass * g_class)
       (GstCollectPadsFunction) gst_ffmpegmux_collected, ffmpegmux);
 
   ffmpegmux->context = avformat_alloc_context ();
-  ffmpegmux->context->oformat = oclass->in_plugin;
+  ffmpegmux->context->oformat = (struct AVOutputFormat *) oclass->in_plugin;
   ffmpegmux->context->nb_streams = 0;
   ffmpegmux->opened = FALSE;
 
@@ -486,6 +486,9 @@ gst_ffmpegmux_setcaps (GstPad * pad, GstObject * parent, GstCaps * caps)
   /* copy over the aspect ratios, ffmpeg expects the stream aspect to match the
    * codec aspect. */
   st->sample_aspect_ratio = st->codecpar->sample_aspect_ratio;
+  /* copy over the frame rate to be used in the container format. */
+  st->time_base.num = tmp.time_base.num;
+  st->time_base.den = tmp.time_base.den;
 
   GST_LOG_OBJECT (pad, "accepted caps %" GST_PTR_FORMAT, caps);
   return TRUE;
@@ -793,6 +796,7 @@ gst_ffmpegmux_change_state (GstElement * element, GstStateChange transition)
       if (ffmpegmux->opened) {
         ffmpegmux->opened = FALSE;
         gst_ffmpegdata_close (ffmpegmux->context->pb);
+        ffmpegmux->context->pb = NULL;
       }
       break;
     case GST_STATE_CHANGE_READY_TO_NULL:
@@ -868,6 +872,7 @@ gst_ffmpegmux_register (GstPlugin * plugin)
   GType type;
   const AVOutputFormat *in_plugin;
   void *i = 0;
+  enum AVCodecID *video_ids = NULL, *audio_ids = NULL;
 
   GST_LOG ("Registering muxers");
 
@@ -921,6 +926,12 @@ gst_ffmpegmux_register (GstPlugin * plugin)
       }
     }
 
+    if (!gst_ffmpeg_formatid_get_codecids (in_plugin->name, &video_ids,
+            &audio_ids, in_plugin)) {
+      GST_LOG ("Ignoring muxer %s because no sink caps", in_plugin->name);
+      continue;
+    }
+
     if (gst_ffmpegmux_get_replacement (in_plugin->name))
       rank = GST_RANK_NONE;
 
